@@ -9,6 +9,7 @@ from microt_compliance_matrix import utils
 
 target_file_pattern = 'phone_battery_clean*.csv'
 
+
 def validate_dates_before_after(intermediate_participant_path, date_in_study):
     validated_date_list = []
 
@@ -40,7 +41,6 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
         if len(one_day_after_log_paths) != 0:
             validated_date_list.append(one_date_after)
 
-
     return validated_date_list
 
 
@@ -59,7 +59,11 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         csv_path_list = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
 
         csv_path = csv_path_list[0]
-        df_day = pd.read_csv(csv_path)
+        try:
+            df_day = pd.read_csv(csv_path)
+        except pd.errors.EmptyDataError:
+            raise Exception("pandas.errors.EmptyDataError (battery_level) : " + csv_path)
+
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
             df_logs_combined = pd.concat([df_logs_combined, df_day])
@@ -70,13 +74,15 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     df_logs_combined.reset_index(inplace=True, drop=True)
     try:
         df_logs_combined["Local_Time"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
-                                             list(df_logs_combined["Local_Time"])]
+                                          list(df_logs_combined["Local_Time"])]
 
         # converter2 = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
         df_logs_combined['Local_Timestamp'] = pd.Series(map(converter, df_logs_combined["Local_Time"]))
         df_logs_combined['Date'] = df_logs_combined['Local_Timestamp'].dt.date
     except IndexError:
-        raise Exception("IndexError: list index out of range (battery_level) : " + intermediate_participant_path + sep + date_in_study + str(list(df_logs_combined["Local_Time"])))
+        raise Exception(
+            "IndexError: list index out of range (battery_level) : " + intermediate_participant_path + sep + date_in_study + str(
+                list(df_logs_combined["Local_Time"])))
     except Exception:
         raise Exception("Exception (battery_level) : " + intermediate_participant_path + sep + date_in_study)
 
@@ -90,7 +96,6 @@ def find_closest_time(prompt_time, subset_time_list):
 
 
 def match_feature(prompt_local_datetime_series, df_logs_combined):
-
     print("     --- start matching")
     matched_battery_level_list = []
     matched_charging_status_list = []
